==> portal-1.1.16-201908300038-sources.jar: com/gtis/portal/entity/PfWorkFlowEvent.java <==
package com.gtis.portal.entity;

import javax.persistence.*;
import java.io.Serializable;

/**
 * @author <a href="mailto:songhaowen@gtmap.cn">ray</a>
 * @version 1.0, 2017/11/15
 * @description 不动产登记服务
 */
@Entity
@Table(name = "PF_WORKFLOWEVENT")
public class PfWorkFlowEvent implements Serializable {
    @Id
    @Column
    private String id;
    @Column(name = "WORKFLOW_DEFINITION_ID")
    private String workFlowDefinitionId;
    @Column(name = "WORKFLOW_NAME")
    private String workFlowName;
    @Column(name = "ACTIVITY_DEFINITION_ID")
    private String activityDefinitionId;
    @Column(name = "WORKFLOW_EVENT_NAME")
    private String workFlowEventName;
    @Column(name = "WORKFLOW_EVENT_URL")
    private String workFlowEventUrl;
    @Column(name = "WORKFLOW_EVENT_ASYN")
    private String workFlowEventAsyn;
    @Column(name = "WORKFLOW_EVENT_ORDER")
    private Integer workFlowEventOrder;
    @Column(name = "TARGET_ACTIVITY_DEFINITION_ID")
    private String targetActivityDefinitionId;

    @Column(name = "TARGET_ACTIVITY_DEFINITIONNAME")
    private String targetActivityDefinitionName;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getWorkFlowDefinitionId() {
        return workFlowDefinitionId;
    }

    public void setWorkFlowDefinitionId(String workFlowDefinitionId) {
        this.workFlowDefinitionId = workFlowDefinitionId;
    }

    public String getWorkFlowName() {
        return workFlowName;
    }

    public void setWorkFlowName(String workFlowName) {
        this.workFlowName = workFlowName;
    }

    public String getActivityDefinitionId() {
        return activityDefinitionId;
    }

    public void setActivityDefinitionId(String activityDefinitionId) {
        this.activityDefinitionId = activityDefinitionId;
    }

    public String getWorkFlowEventName() {
        return workFlowEventName;
    }

    public void setWorkFlowEventName(String workFlowEventName) {
        this.workFlowEventName = workFlowEventName;
    }

    public String getWorkFlowEventUrl() {
        return workFlowEventUrl;
    }

    public void setWorkFlowEventUrl(String workFlowEventUrl) {
        this.workFlowEventUrl = workFlowEventUrl;
    }

    public String getWorkFlowEventAsyn() {
        return workFlowEventAsyn;
    }

    public void setWorkFlowEventAsyn(String workFlowEventAsyn) {
        this.workFlowEventAsyn = workFlowEventAsyn;
    }

    public Integer getWorkFlowEventOrder() {
        return workFlowEventOrder;
    }

    public void setWorkFlowEventOrder(Integer workFlowEventOrder) {
        this.workFlowEventOrder = workFlowEventOrder;
    }

    public String getTargetActivityDefinitionId() {
        return targetActivityDefinitionId;
    }

    public void setTargetActivityDefinitionId(String targetActivityDefinitionId) {
        this.targetActivityDefinitionId = targetActivityDefinitionId;
    }

    public String getTargetActivityDefinitionName() {
        return targetActivityDefinitionName;
    }

    public void setTargetActivityDefinitionName(String targetActivityDefinitionName) {
        this.targetActivityDefinitionName = targetActivityDefinitionName;
    }
}

==> portal-1.1.20-202004140543-sources.jar: com/gtis/portal/entity/PfWorkFlowEvent.java <==
package com.gtis.portal.entity;

import javax.persistence.*;
import java.io.Serializable;

/**
 * @author <a href="mailto:songhaowen@gtmap.cn">ray</a>
 * @version 1.0, 2017/11/15
 * @description 不动产登记服务
 */
@Entity
@Table(name = "PF_WORKFLOWEVENT")
public class PfWorkFlowEvent implements Serializable {
    @Id
    @Column
    private String id;
    @Column(name = "WORKFLOW_DEFINITION_ID")
    private String workFlowDefinitionId;
    @Column(name = "WORKFLOW_NAME")
    private String workFlowName;
    @Column(name = "ACTIVITY_DEFINITION_ID")
    private String activityDefinitionId;
    @Column(name = "WORKFLOW_EVENT_NAME")
    private String workFlowEventName;
    @Column(name = "WORKFLOW_EVENT_URL")
    private String workFlowEventUrl;
    @Column(name = "WORKFLOW_EVENT_ASYN")
    private String workFlowEventAsyn;
    @Column(name = "WORKFLOW_EVENT_ORDER")
    private Integer workFlowEventOrder;
    @Column(name = "TARGET_ACTIVITY_DEFINITION_ID")
    private String targetActivityDefinitionId;

    @Column(name = "TARGET_ACTIVITY_DEFINITIONNAME")
    private String targetActivityDefinitionName;

    @Column(name = "WORKFLOW_EVENT_METHOD")
    private String workFlowEventMethod;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getWorkFlowDefinitionId() {
        return workFlowDefinitionId;
    }

    public void setWorkFlowDefinitionId(String workFlowDefinitionId) {
        this.workFlowDefinitionId = workFlowDefinitionId;
    }

    public String getWorkFlowName() {
        return workFlowName;
    }

    public void setWorkFlowName(String workFlowName) {
        this.workFlowName = workFlowName;
    }

    public String getActivityDefinitionId() {
        return activityDefinitionId;
    }

    public void setActivityDefinitionId(String activityDefinitionId) {
        this.activityDefinitionId = activityDefinitionId;
    }

    public String getWorkFlowEventName() {
        return workFlowEventName;
    }

    public void setWorkFlowEventName(String workFlowEventName) {
        this.workFlowEventName = workFlowEventName;
    }

    public String getWorkFlowEventUrl() {
        return workFlowEventUrl;
    }

    public void setWorkFlowEventUrl(String workFlowEventUrl) {
        this.workFlowEventUrl = workFlowEventUrl;
    }

    public String getWorkFlowEventAsyn() {
        return workFlowEventAsyn;
    }

    public void setWorkFlowEventAsyn(String workFlowEventAsyn) {
        this.workFlowEventAsyn = workFlowEventAsyn;
    }

    public Integer getWorkFlowEventOrder() {
        return workFlowEventOrder;
    }

    public void setWorkFlowEventOrder(Integer workFlowEventOrder) {
        this.workFlowEventOrder = workFlowEventOrder;
    }

    public String getTargetActivityDefinitionId() {
        return targetActivityDefinitionId;
    }

    public void setTargetActivityDefinitionId(String targetActivityDefinitionId) {
        this.targetActivityDefinitionId = targetActivityDefinitionId;
    }

    public String getTargetActivityDefinitionName() {
        return targetActivityDefinitionName;
    }

    public void setTargetActivityDefinitionName(String targetActivityDefinitionName) {
        this.targetActivityDefinitionName = targetActivityDefinitionName;
    }

    public String getWorkFlowEventMethod() {
        return workFlowEventMethod;
    }

    public void setWorkFlowEventMethod(String workFlowEventMethod) {
        this.workFlowEventMethod = workFlowEventMethod;
    }
}
